@@ -21,9 +21,11 @@ pub mod errors;
 pub mod fs_util;
 pub mod inspector_server;
 pub mod js;
-pub mod metrics;
 pub mod ops;
 pub mod permissions;
 pub mod tokio_util;
 pub mod web_worker;
 pub mod worker;
+
+mod worker_bootstrap;
+pub use worker_bootstrap::BootstrapOptions;
